==> libgnome-java-2.10.1.tar.bz2: libgnome-java-2.10.1/src/java/org/gnu/gnome/DruidPageStandard.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gnome;
import org.gnu.gdk.Color;
import org.gnu.gdk.Pixbuf;
import org.gnu.glib.GObject;
import org.gnu.glib.Handle;
import org.gnu.glib.Type;
import org.gnu.gtk.VBox;
import org.gnu.gtk.Widget;
/**
 * A widget representing pages that are not initial or terminal pages of a Druid.
 */
public class DruidPageStandard extends DruidPage {
	/**
	 * Construct a new DruidPageStandard object
	 */
	public DruidPageStandard() {
		super(gnome_druid_page_standard_new());
	}
	
	/**
	 * Construct a new DruidPageStandard object
	 */
	public DruidPageStandard(String title, Pixbuf logo, Pixbuf topWatermark) {
		super(gnome_druid_page_standard_new_with_vals(title, logo.getHandle(), topWatermark.getHandle()));
	}
	
	/**
	 * Constructs a new DruidPageStandard object form a native resource.
	 * @param handle The handle to the native resource.
	 */
	public DruidPageStandard(Handle handle) {
	    super(handle);
	}
	
	/**
	 * Set the title for the page.
	 */
	public void setTitle(String title) {
		gnome_druid_page_standard_set_title(getHandle(), title);
	}
	
	/**
	 * Set the logo for the page.
	 */
	public void setLogo(Pixbuf logo) {
		gnome_druid_page_standard_set_logo(getHandle(), logo.getHandle());
	}
	
	/**
	 * Set the watermark for the page.
	 */
	public void setTopWatermark(Pixbuf watermark) {
		gnome_druid_page_standard_set_top_watermark(getHandle(), watermark.getHandle());
	}
	
	/**
	 * Set the title foreground for the page.
	 */
	public void setTitleForegroundColor(Color color) {
		gnome_druid_page_standard_set_title_foreground(getHandle(), color.getHandle());
	}
	
	/**
	 * Set the background for the page.
	 */
	public void setBackgroundColor(Color color) {
		gnome_druid_page_standard_set_background(getHandle(), color.getHandle());
	}
	
	/**
	 * Set the logo background color.
	 */
	public void setLogoBackgroundColor(Color color) {
		gnome_druid_page_standard_set_logo_background(getHandle(), color.getHandle());
	}
	
	/**
	 * Set the contents background for the page.
	 */
	public void setContentsBackgroundColor(Color color) {
		gnome_druid_page_standard_set_contents_background(getHandle(), color.getHandle());
	}
	
	/**
	 * Get the layout control for the page.  This can be used to add widgets
	 * the the main area of the page.
	 */
	public VBox getLayout() {
		Handle hndl = getVbox(getHandle());
		GObject obj = getGObjectFromHandle(hndl);
		if (null != obj)
			return (VBox)obj;
		return new VBox(hndl);
	}
	
	/**
	 * Convenience method to append a widget.
	 */
	public void appendItem(String question, Widget item, String additionalInfo) {
		gnome_druid_page_standard_append_item(getHandle(), question, item.getHandle(), additionalInfo);
	}

	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gnome_druid_page_standard_get_type());
	}


	native static final protected Handle getVbox(Handle cptr);
	native static final protected String getTitle(Handle cptr);
	native static final protected Handle getLogo(Handle cptr);
	native static final protected Handle getTopWatermark(Handle cptr);
	native static final protected Handle getTitleForeground(Handle cptr);
	native static final protected Handle getBackground(Handle cptr);
	native static final protected Handle getLogoBackground(Handle cptr);
	native static final protected Handle getContentsBackground(Handle cptr);
	native static final protected int gnome_druid_page_standard_get_type();
	native static final protected Handle gnome_druid_page_standard_new();
	native static final protected Handle gnome_druid_page_standard_new_with_vals(String title, Handle logo, Handle topWatermark);
	native static final protected void gnome_druid_page_standard_set_title(Handle page, String title);
	native static final protected void gnome_druid_page_standard_set_logo(Handle page, Handle logoImage);
	native static final protected void gnome_druid_page_standard_set_top_watermark(Handle page, Handle topWatermarkImage);
	native static final protected void gnome_druid_page_standard_set_title_foreground(Handle page, Handle color);
	native static final protected void gnome_druid_page_standard_set_background(Handle page, Handle color);
	native static final protected void gnome_druid_page_standard_set_logo_background(Handle page, Handle color);
	native static final protected void gnome_druid_page_standard_set_contents_background(Handle page, Handle color);
	native static final protected void gnome_druid_page_standard_append_item(Handle page, String questionMnemonic, Handle item, String additionalInfoMarkup);

}

==> libgnome-java-2.11.4.tar.bz2: libgnome-java-2.11.4/src/java/org/gnu/gnome/DruidPageStandard.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gnome;

import org.gnu.gdk.Color;
import org.gnu.gdk.Pixbuf;
import org.gnu.glib.GObject;
import org.gnu.glib.Type;
import org.gnu.gtk.VBox;
import org.gnu.gtk.Widget;
import org.gnu.javagnome.Handle;

/**
 * A widget representing pages that are not initial or terminal pages of a Druid.
 */
public class DruidPageStandard extends DruidPage {
	/**
	 * Construct a new DruidPageStandard object
	 */
	public DruidPageStandard() {
		super(gnome_druid_page_standard_new());
	}
	
	/**
	 * Construct a new DruidPageStandard object
	 */
	public DruidPageStandard(String title, Pixbuf logo, Pixbuf topWatermark) {
		super(gnome_druid_page_standard_new_with_vals(title, logo.getHandle(), topWatermark.getHandle()));
	}
	
	/**
	 * Constructs a new DruidPageStandard object form a native resource.
	 * @param handle The handle to the native resource.
	 */
	public DruidPageStandard(Handle handle) {
	    super(handle);
	}
	
	/**
	 * Set the title for the page.
	 */
	public void setTitle(String title) {
		gnome_druid_page_standard_set_title(getHandle(), title);
	}
	
	/**
	 * Set the logo for the page.
	 */
	public void setLogo(Pixbuf logo) {
		gnome_druid_page_standard_set_logo(getHandle(), logo.getHandle());
	}
	
	/**
	 * Set the watermark for the page.
	 */
	public void setTopWatermark(Pixbuf watermark) {
		gnome_druid_page_standard_set_top_watermark(getHandle(), watermark.getHandle());
	}
	
	/**
	 * Set the title foreground for the page.
	 */
	public void setTitleForegroundColor(Color color) {
		gnome_druid_page_standard_set_title_foreground(getHandle(), color.getHandle());
	}
	
	/**
	 * Set the background for the page.
	 */
	public void setBackgroundColor(Color color) {
		gnome_druid_page_standard_set_background(getHandle(), color.getHandle());
	}
	
	/**
	 * Set the logo background color.
	 */
	public void setLogoBackgroundColor(Color color) {
		gnome_druid_page_standard_set_logo_background(getHandle(), color.getHandle());
	}
	
	/**
	 * Set the contents background for the page.
	 */
	public void setContentsBackgroundColor(Color color) {
		gnome_druid_page_standard_set_contents_background(getHandle(), color.getHandle());
	}
	
	/**
	 * Get the layout control for the page.  This can be used to add widgets
	 * the the main area of the page.
	 */
	public VBox getLayout() {
		Handle hndl = getVbox(getHandle());
		GObject obj = getGObjectFromHandle(hndl);
		if (null != obj)
			return (VBox)obj;
		return new VBox(hndl);
	}
	
	/**
	 * Convenience method to append a widget.
	 */
	public void appendItem(String question, Widget item, String additionalInfo) {
		gnome_druid_page_standard_append_item(getHandle(), question, item.getHandle(), additionalInfo);
	}

	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gnome_druid_page_standard_get_type());
	}


	native static final protected Handle getVbox(Handle cptr);
	native static final protected String getTitle(Handle cptr);
	native static final protected Handle getLogo(Handle cptr);
	native static final protected Handle getTopWatermark(Handle cptr);
	native static final protected Handle getTitleForeground(Handle cptr);
	native static final protected Handle getBackground(Handle cptr);
	native static final protected Handle getLogoBackground(Handle cptr);
	native static final protected Handle getContentsBackground(Handle cptr);
	native static final protected int gnome_druid_page_standard_get_type();
	native static final protected Handle gnome_druid_page_standard_new();
	native static final protected Handle gnome_druid_page_standard_new_with_vals(String title, Handle logo, Handle topWatermark);
	native static final protected void gnome_druid_page_standard_set_title(Handle page, String title);
	native static final protected void gnome_druid_page_standard_set_logo(Handle page, Handle logoImage);
	native static final protected void gnome_druid_page_standard_set_top_watermark(Handle page, Handle topWatermarkImage);
	native static final protected void gnome_druid_page_standard_set_title_foreground(Handle page, Handle color);
	native static final protected void gnome_druid_page_standard_set_background(Handle page, Handle color);
	native static final protected void gnome_druid_page_standard_set_logo_background(Handle page, Handle color);
	native static final protected void gnome_druid_page_standard_set_contents_background(Handle page, Handle color);
	native static final protected void gnome_druid_page_standard_append_item(Handle page, String questionMnemonic, Handle item, String additionalInfoMarkup);

}
